@@ -29,7 +29,7 @@
 #' @param allow_failure logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
 #' @import data.table
 #' @export
-#' @returns data.frame with a raw meteorological measurements in 10-min intervals. 
+#' @returns data.table with a raw meteorological measurements in 10-min intervals. 
 #' Please note that this dataset is not validated by experts and may contain invalid values.
 #' @examples 
 #' \donttest{
@@ -47,7 +47,7 @@ meteo_imgw_datastore = function(year,
                                 stations = NULL,
                                 coords = TRUE,
                                 allow_failure = TRUE) {
-  
+  # nocov start
   # assertions for year
   if (!any(is.character(year) || is.numeric(year))) {
     stop("year argument must be character or numeric")
@@ -73,6 +73,7 @@ meteo_imgw_datastore = function(year,
                             coords)
   }
 }
+# nocov end
 
 #' @keywords internal
 #' @noRd
@@ -126,7 +127,7 @@ meteo_imgw_datastore_bp = function(year,
       message("IMGW datastore does not contain data for ", paste(basename(urls[i])), ". skipping\n")
     }
 
-    files_to_read = dir(tmp_dir, full.names = TRUE, pattern = paste0(dict$V2, collapse = "|"))
+    files_to_read = dir(tmp_dir, full.names = TRUE, pattern = paste0(dict$V2, collapse = "|"), recursive = TRUE)
     files_to_read = files_to_read[file.size(files_to_read) > 0]
     
     all_data[[i]] = data.table::rbindlist(
@@ -139,7 +140,7 @@ meteo_imgw_datastore_bp = function(year,
                                            select = c("V1", "V2", "V3", "V4")
              )
       ),
-      fill = TRUE)
+      fill = TRUE, use.names = TRUE)
     
     if (!is.null(stations)) {
       all_data[[i]] = all_data[[i]][all_data[[i]]$V1 %in% telemetry_stations$id, ]
@@ -148,7 +149,7 @@ meteo_imgw_datastore_bp = function(year,
     unlink(c(temp, temp2, tmp_dir), recursive = TRUE)
   }
 
-  all_data = data.table::rbindlist(all_data, fill = TRUE)
+  all_data = data.table::rbindlist(all_data, fill = TRUE, use.names = TRUE)
   all_data = all_data[dict, on = 'V2', param := i.parameter]
   all_data = data.table::dcast(all_data, V1 + V3  ~ param, value.var = "V4")
   all_data$V3 = as.POSIXct(all_data$V3, tz = "UTC")
@@ -161,5 +162,9 @@ meteo_imgw_datastore_bp = function(year,
   
   colnames(all_data)[which(colnames(all_data) %in% c("V1", "V3"))] = c("id", "date_time")
   
-  return(as.data.frame(all_data))
+  # change class of columns in data.frame to numeric:
+  cnames_to_change = colnames(all_data)[colnames(all_data) %in% dict$parameter]
+  all_data[, (cnames_to_change) := lapply(.SD, as.numeric), .SDcols = cnames_to_change]
+  
+  return(all_data)
 }
