@@ -7,6 +7,8 @@
 #' @param add_map logical - whether to draw a map based on downloaded dataset (requires `maps` package)
 #' @param allow_failure logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
 #' @importFrom XML readHTMLTable
+#' @importFrom utils object.size
+#' 
 #' @export
 #' @return A data.frame with columns describing the synoptic stations in selected countries where each row represent a statation.
 #' If `add_map = TRUE` additional map of downloaded data is visualized.
@@ -53,14 +55,21 @@ stations_ogimet_bp = function(country = country, date = date, add_map = add_map)
   ndays = 1
   linkpl2 = paste0("http://ogimet.com/cgi-bin/gsynres?lang=en&state=",country,"&osum=no&fmt=html&ord=REV&ano=",year,"&mes=",month,"&day=",day,"&hora=06&ndays=1&Send=send")
   
-  temp = tempfile()
-  test_url(link = linkpl2, output = temp)
+  body = httr::GET(linkpl2,
+                   httr::add_headers(
+                     `User-Agent` = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:143.0) Gecko/20100101 Firefox/143.0",
+                     `Accept` = "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
+                     `Accept-Language` = "pl,en-US;q=0.7,en;q=0.3",
+                     `Referer` = "https://ogimet.com/resynops.phtml.en",
+                     `Cookie` = "cookieconsent_status=dismiss; ogimet_serverid=huracan|aNaPt|aNaPj"
+                   ))
+  body = httr::content(body, as = "text", encoding = "UTF-8")
+  
    
   # run only if downloaded file is valid
-  if (!is.na(file.size(temp)) & (file.size(temp) > 0)) {
+  if (!is.na(body) & (object.size(body) > 0)) {
    
-    a = readLines(temp)
-    a = paste(a, sep = "", collapse = "")
+    a = paste(body, sep = "", collapse = "")
     b = strsplit(a, "Decoded synops since")
     
     b1 = lapply(b, function(x) substr(x, 1, 400))
